Crate tari_p2p

Crate tari_p2p 

Re-exports

pub use transport::Socks5TransportConfig;
pub use transport::TcpTransportConfig;
pub use transport::TorTransportConfig;
pub use transport::TransportConfig;
pub use transport::TransportType;

Modules

comms_connector
dns
domain_message
initialization
peer
peer_seeds
proto
services
tari_message
transport

Structs

P2pConfig
Configuration for a comms node
PeerSeedsConfig
Peer seed configuration

Enums

Network
Represents the available Tari p2p networks. Only nodes with matching byte values will be able to connect, so these should never be changed once released.
SocksAuthentication
TorControlAuthentication

Constants

MAJOR_NETWORK_VERSION
Major network version. Peers will refuse connections if this value differs
MINOR_NETWORK_VERSION
Minor network version. This should change with each time the network protocol has changed in a backward-compatible way.