Re-exports
pub use transport::Socks5TransportConfig;pub use transport::TcpTransportConfig;pub use transport::TorTransportConfig;pub use transport::TransportConfig;pub use transport::TransportType;
Modules
Structs
- P2pConfig
- Configuration for a comms node
- Peer
Seeds Config - Peer seed configuration
Enums
- Network
- Represents the available Tari p2p networks. Only nodes with matching byte values will be able to connect, so these should never be changed once released.
- Socks
Authentication - TorControl
Authentication
Constants
- MAJOR_
NETWORK_ VERSION - Major network version. Peers will refuse connections if this value differs
- MINOR_
NETWORK_ VERSION - Minor network version. This should change with each time the network protocol has changed in a backward-compatible way.